@@ -1,5 +1,8 @@
 """
-Tools for managing command line tools.
+Provide the workings for the twanager command line tool.
+twanager calls handle() in this module and makes available
+all commands that have been put into the COMMANDS dictionary
+by the make_command() decorator.
 """
 
 import logging
@@ -32,10 +35,10 @@ def make_command():
 
 
 @make_command()
-def usage(*args):
+def usage(args):
     """List this help"""
     if args:
-        std_error_message('ERROR: ' + ' '.join(args) + '\n')
+        std_error_message('ERROR: ' + args + '\n')
     for key in sorted(COMMANDS):
         std_error_message('%10s: %s' % (key, COMMANDS[key].description))
     sys.exit(1)
@@ -64,7 +67,7 @@ def handle(args):
             imported_module = __import__(plugin, {}, {}, ['init'])
             imported_module.init(config)
     except KeyError:
-        pass # no plugins
+        pass  # no plugins
 
     candidate_command = None
     try:
